@@ -61,7 +61,7 @@ def init(args):
                 
         sensors_sapofto = SAPOFTO.SAPOFTO('sensors',nwbfile_in.get_scratch('nwborglab_sensors'), case_sensitive=True)
         overview_sapofto = SAPOFTO.SAPOFTO('OVERVIEW',nwbfile_in.get_scratch('nwborglab_overview'))
-        session_skeleton_sapofto = SAPOFTO.SAPOFTO('SKELETONS',nwbfile_in.get_scratch('nwborglab_session_skeleton'))
+        session_skeleton_sapofto = SAPOFTO.SAPOFTO('SESSION_SKELETONS',nwbfile_in.get_scratch('nwborglab_session_skeleton'))
         #session_skeleton_sapofto = nwbfile_in.get_scratch('nwborglab_session_source_code')
         
         SAPOFTO.recursiveFolderWrite(sensors_sapofto, os.getcwd(), safe_mode=True)
